# Cho-Util

![Python package](https://github.com/yycho0108/cho-util/workflows/Python%20package/badge.svg)

Common utility functions generally targetted for robotics.

Currently mostly implements mathematical operations and application-related utilities.
